  --------------------------------------------------------------------------
    README.TXT traduzido para o Portugus (Brasil) por: Rafael Prado Rocchi
      Se tiver duvida ou sugesto sobre a traduo contacte-me via e-mail
                 no seguinte endereo: brmame@zipmail.com.br
  	    Para obter a ultima versao do MAME em portugues acesse:
  		         http://members.xoom.com/br_mame
                             ------------------------
          No envie suas sugestes e/ou dvidas sobre a traduo para o 
                    MAME Team pois eles no iro lhe responder.
  --------------------------------------------------------------------------



              M.A.M.E.  -  Multiple Arcade Machine Emulator
     Copyright (C) 1997, 1998, 1999  by Nicola Salmoria and the MAME team

Por favor note que muitas pessoas ajudaram com este projeto, tanto diretamente
or por ter mostrado o codigo fonte usado para escrever os drivers. Ns no 
estamos tentando nos apropriar dos mritos que no so nossos. Veja a seo
'acknowledgments' para uma lista dos contribuidores, entretanto note que esta
lista est muito imcompleta. Veja tambm a seo de CREDITOS no emulador para
ver as pessoas que contribuiram para um driver especfico. Novamente, a lista
pode estar imcompleta. Ns nos desculpamos desde ja por alguma omisso.

Todas as marcas citadas neste documento so propriedades de seus respectivos
proprietrios.


Uso e Licensa de Distribuio
-----------------------------

I. Razo
----------
   MAME  um projeto no lucrativo. O seu objetivo principal  ser uma referncia 
   do funcionamento interno das maquinas emuladas. Isso  feito apenas por razes 
   educacionais e para preservar muitos jogos histricos do esquecimento no qual
   eles ficaro quando o hardware deles para de funcionar.
   Claro que para preservar os jogos deve-se tambm ser possvel joga-los; voc
   pode ver isso como um efeito colateral.
   No  a nossa inteno infringir nenhuma lei de copyright ou patentes dos
   jogos originais. Todo o cdigo fonte  nosso e disponvel livremente.
   Para funcionar, o emulador precisa das ROMs da maquina original, que deve
   ser fornecida pelo usurio. Nenhuma poro do codigo original das ROMs est
   includa no arquivo executvel.


II. Custo
---------
   MAME  de graa. O cdigo fonte  de graa. Vende-lo no  permitido.

III. Imagens das ROMs
---------------------
   Voc no pode distribuir o MAME e imagens (arquivos) ROMs no mesmo meio
   fisico. Voc pode torna-los disponiveis para download dentro do mesmo site
   na internet, mas apenas se alertar os usurios sobre os copyrights das ROMs
   e sobre os assuntos legais envolvidos. Voc NO tem permisso para tornar o
   MAME disponvel para downlad junto com um grande arquivo contendo todas as
   ROMs suportadas, ou qualquer arquivo contendo maus de um jogo cada.
   Voc no tem permisso para distribuir o MAME em qualquer forma se voc 
   vender, patrocinar ou publicar CD-ROMs ilegais ou em outro meio contendo as
   imagens ROMs. Note que esta restrio se aplica mesmo se voc nao lucrar 
   diretamente com isso.
   Esta restrio obviamente no se aplica caso os CD-ROMs sejam publicados 
   pelos detentores dos direitos das ROMs.


IV. Distribuio do Codigo Fonte
--------------------------------
   Se voc distribuir o binrio, voc deve tambm distribuir o cdigo fonte.
   Se no puder fazer isso, voc deve indicar um lugar onde o cdigo fonte
   possa ser obtido.

V. Integridade da Distribuio
-------------------------------
   Este captulo se aplica  distribuio oficial do MAME. Veja o prximo capi-
   tulo para saber sobre as limitaes na distribuio de trabalhos derivados.
   MAME deve ser distribuido apenas nos arquivos originais. Voc nao tem
   direito de distribuir uma verso modificada, nem remover ou adicinar arquivos
   ao pacote.
	
VI. Re-uso do Cdigo Fonte
--------------------------
   Este captulo pode no se aplicar a pores especficas do MAME (ex. emu-
   lador de CPU) as quais apresentam notas de copyright diferentes.
   O cdigo fonta no pode ser utilizado num produto comercial sem a permisso
   por escrito dos autores. Uso em produtos no comerciais  permitido e 
   certamente encorajado; entretanto se voc utilizar pores do cdigo fonte
   do MAME em seu programa, voc deve tornar o codigo-fonte livremente disponivel.
   Uso da _informao_ contida no cdigo fonte  livre para qualquer uso. Entretando,
   dado o grande tempo e energia gastos para coletar essas informaes, ns
   apreciaramos se voc tornasse as informaes adicionais que voc tenha 
   livremente disponvel.   


VII. Trabalhos Derivados
------------------------
   Trabalhos derivados so permitidos (desde que o codigo fontes esteja dispo-
   nivel), porm so desencorajados: MAME  um projeto que evolui continuamente,
   e voce deve, no seu melhor interesse, submeter suas contribuies ao time de
   desenvolvimento, para que seja integrada  distribuio principal. 
   Existe um certo numero de drivers no codigo fonte que sao desabilitados na 
   distribuicao oficial. Habilitar eles NAO e considerado um trabalho derivado,
   e a distribuicao de executaveis contendo esses drivers habilitados eh 
   extremamente PROIBIDA.


Como nos contactar
------------------

A pagina oficial do MAME est em http://mame.retrogames.com/. Voc poder
sempre encontrar a ltima versao la, incluindo verses BETA e informaes
sobre o que est em desenvolvimento.

Aqui esto algumas das pessoas que contribuem para o MAME. Se voc tem comentrios,
sugestes ou encontrou algum BUG em algum driver, cheque os Creditos do driver
para encontrar a pessoa que trabalhou nele, e envie seus comentrios para essa
pessoa. Se voc nao sabe quem contactar, escreva par Nicola. Se voc tem comentrios
especficos para outro sistema que nao seja o DOS (ex Mac, Win32, Unix), eles devem
ser enviados aos respectivos mantenedores dessas verses (ou ports) (cheque a 
documentao pra saber quem eles sao). NAO MANDE PARA NICOLA - eles sero ignorados.

Nicola Salmoria    MC6489@mclink.it

Mike Balfour       mab22@po.cwru.edu
Aaron Giles        agiles@sirius.com
Chris Moore        chris.moore@writeme.com
Brad Oliver        bradman@primenet.com
Andrew Scott       ascott@utkux.utcc.utk.edu
Zsolt Vasvari      vaszs01@banet.net


NO ENVIE ARQUIVOS BINARIOS ATACHADOS SEM ANTES PERGUNTAR, *ESPECIALMENTE* ARQUIVOS ROM.

ESSES ENDEREOS NAO SO PARA SUPORTE. Perguntas sobre suporte enviadas  esses
endereos sero ignoradas. Por favor entenda que este  um projeto livre, mais
voltado para usurios esperientes. Nos nao temos recursos para criar um suporte
ao usurio. Basicamante, se voc no conseguir fazer o emulador funcionar, voc
est a s.
Primeiro de tudo, leia os documento com ateno. Se mesmo assim no conseguir
encontrar uma resposta para sua pergunta, tente checar as sees para principiantes
que muitos sites sobre emulao possuem, ou pergunte em algum newsgroup apropriado
(ex. comp.emulators.misc) ou na board de discusso oficial do MAME em:
http://www.macmame.org/wwwboard/mame/

Para ajuda em compilar o MAME, cheque essas paginas:
http://zan.emuunlim.com/mame/compile/compilemame.html
http://zan.emuunlim.com/mame/compile/compilemamebeta.html

Tambm, NAO PEA PARA NOVOS JOGOS SEREM ADICIONADOS, a no ser que voc tenha
informao sobre o hardware ou, ainda melhor, possua a placa e tem conhecimento
tecnico necessrio para nos ajudar.
Por favor no nos envie informaes disponveis na Internet - ns somos
perfeitamente capazes de encontra-las sozinhos, obrigado.



Acknowledgments
---------------

Primeiro de tudo, obrigado para llard van der Bas (avdbas@wi.leidenuniv.nl)
por iniciar o repositrio sobre programao de arcades (Arcade Emulation 
Programming Repository) em http://valhalla.ph.tn.tudelft.nl/emul8
Sem o repositrio, eu nunca iria nem tentar escrever um emulador.
Infelizmente, o repositrio original est fechado, mas seu esprito ainda
vive no MAME.


Z80 emulator Copyright (c) 1998 Juergen Buchmueller, all rights reserved.
M6502 emulator Copyright (c) 1998 Juergen Buchmueller, all rights reserved.
I86 emulator by David Hedley, modified by Fabrice Frances (frances@ensica.fr)
M6809 emulator by John Butler, based on L.C. Benschop's 6809 Simulator V09.
M6808 based on L.C. Benschop's 6809 Simulator V09.
80x86 asm M6808 emulator Copyright 1998, Neil Bradley, All rights reserved
M68000 emulator Copyright 1999 Karl Stenerud.  All rights reserved.
80x86 M68000 emulator Copyright 1998, Mike Coates, Darren Olafson.
8039 emulator by Mirko Buffoni, based on 8048 emulator by Dan Boris.
T-11 emulator Copyright (C) Aaron Giles 1998
TMS34010 emulator by Alex Pasadyn and Zsolt Vasvari.
TMS9900 emulator by Andy Jones, based on original code by Ton Brouwer.

TMS5220 emulator by Frank Palazzolo.
AY-3-8910 emulation based on various code snippets by Ville Hallik,
  Michael Cuddy, Tatsuyuki Satoh, Fabrice Frances, Nicola Salmoria.
YM-2203 and YM-2151 emulation by Tatsuyuki Satoh.
POKEY emulator by Ron Fries (rfries@aol.com).
Many thanks to Eric Smith, Hedley Rainnie and Sean Trowbridge for information
   on the Pokey random number generator.
NES sound hardware info by Jeremy Chadwick and Hedley Rainne.
YM3812 and YM3526 emulation by Carl-Henrik Skrstedt.
YM2610 emulation by Hiromitsu Shioya.

Background art by Peter Hirschberg (PeterH@cronuscom.com).

Allegro library by Shawn Hargreaves, 1994/97
SEAL Synthetic Audio Library API Interface Copyright (C) 1995, 1996
   Carlos Hasan. All Rights Reserved.
Video modes created using Tweak 1.6b by Robert Schmidt, who also wrote
   TwkUser.c.
"inflate" code for zip file support by Mark Adler.

Big thanks to Gary Walton (garyw@excels-w.demon.co.uk) for too many things
   to mention them all.



USO
---

MAME [nome do jogo a executar] [opes]

por exemplo

MAME mspacman -soundcard 0    ir executar Ms Pac Man sem som


opes:
-scanlines/-noscanlines (padro: -scanlines)
		Se o modo padro no funciona com seu monitor/placa de video
		(imagem dupla divididas verticalmente), use -noscanlines ou
     		-vesa.
-vesa/-novesa (padro: auto)
         	Decide quanto a usar modos VGS tweaked os modos standard VESA.    
		Note que algums jogos de alta resoluo requerem modos VESA,
		-novesa  ignorado neste caso.
-ntsc           um modo 288x224 com frequencias padroes NTSC. Voce precisar de
		algum hardware adicionar (conversor VGA2TV) para poder utilizar
		isso.
-vesa1          descontinuado. use "-vesa -vesamode vesa1"
-vesa2b         descontinuado. use "-vesa -vesamode vesa2b"
-vesa2l         descontinuado. use "-vesa -vesamode vesa2l"
-vesamode vesa1/vesa2b/vesa2l/vesa3
		Em  conjuno com "-vesa", seleciona os modos VESA a tentar.
                O padro  vesa2l.
-resolution XxY
              	onde X e Y so Largura e Altura (ex: '-resolution 800x600')
	      	voc pode utilizar -XxY (ex: -800x600) como um atalho.
		Autores de frontend devem utilizar -resolution XxY, entretanto.
-320          	descontinuado. Use -320x240.
		Se vc receber um erro '320x240 nao suportado', vc provavelmente
		precisa do Scitech's Display Doctor, que fornece o 'de facto'
		em implementao VESA (http://www.scitechsoft.com)
		Nota: essa  uma boa alternativa para '-640x480 -noscanlines'
-400            mesmo que acima, use -400x300
-512            mesmo que acima, use -512x384
-640            mesmo que acima, use -640x480
-800            mesmo que acima, use -800x600.
-1024           mesmo que acima, use -1024x768
-skiplines N / -skipcolumns N
		Se vc rodar um jogo num modo de vdeo menor que a rea visvel,
 		voc pode ajustar sua posio usando as teclas PGUP PGDN (sozinhas
		para movimentos verticais e junto com SHIFT para movimentos 
		horizontais)
		Voce pode tambm utilizar esses parametros para setar a posio
		inicial: 0  o padro, significando que a tela est centralizada.
		Voc pode especificar tanto valores positivos quanto negativos.
-double/-nodouble (default: auto)
        	Use nodouble para desabilitar a duplicao de pixel em modos VESA
		(mais rapido, porem imagem menor). Use double para forcar a du-
		plicao quando a imagem nao cabe na tela (voc ter que utilizar
  		PGUP e PGDN para fazer o scroll)
-depth n        (default: 16)
		Alguns jogos precisam de modos de 65000 cores para obter graficos
		fieis. Para aumentar a velocidade, voc pode desligar essa funo
		usando '-depth 8', que limita para modos de 256 cores.
-gamma n        (default: 1.2)
		Seta a correo de gama inicial.
-vgafreq n    	onde n pode ser 0 (padro) 1, 2 ou 3.
		use frequencias diferentes para modos de video customizados.
		Isso pode reduzir flicker (piscadas da imagem), especialmente
		no modo 224x288noscanlines. ALERTA: AS FREQUENCIAS USADAS PODEM
		ESTA FORA DAS QUAIS SEU MONITOR PODE ALCANAR, E PODEM AT
		DANIFIC-LO. O RISCO DE USAR ESTAS OPOES  TODO SEU.
-vsync/-novsync (default: -novsync)
		Sincroniza o video com os raios do monitor ao invs de usar
		o timer. Esta opo s pode ser usada se o modo de video se-
		lecionado possui uma taxa de atualizao (refresh) apropriada;
		MAME ir em outro caso se recusar a iniciar, dizendo a taxa de
		atualiaao atual do video e a taxa que deveria ser correta.
		Se voc est utilizando um modo tweaked, MAME ir tentar 
		automaticamente acertar o valor correto para -vgafreq; voce
		pode ainda ultrapassar ele usando a opo -vgafreq. Note:
		o modo 224.288noscanlines no funciona na maioria das placas
		de video. Este modo  utilizado em muitos jogos (ex: Pac Man
		e Galaga). Se ele no funcionar na sua placa, use a verso
		com scanlines ou no use -vsync.
		Se voc est usando um modo VESA voc deve utilizar o programa
		que veio com sua placa de video para acertar a taxa de refresh.
		Note que quando esta opo est ativada, a velocidade NAO vai
		cair caso seu sistema no seja rapido suficiente.
-alwayssynced/-noalwayssynced (default: -noalwayssynced)
		Para muitos modos tweaked VGA, MAME possui 2 definies:
		uma que  mais compatvel, e outra que  menos compatvel mas
		utiliza frequencias compatveis com -vsync. Por padro, a menos
		compatvel  apenas utilizada quando -vsync  requisitado;
		usando essa opo, voc pode fora-la a ser usada sempre.
-ror            rotaciona a imagem no sentido horrio em 90 graus.
-rol            rotaciona a imagem sentido anti-horrio
-flipx          inverte a imagem horizontalmente
-flipy          inverte a imagem verticalmente
                -ror e -rol geram autenticas scnlines *verticais*, dado que voc
	        ir girar o seu monitor.
                PERIGO:
		O monitor  um aparelho eletronico complicado e de alta
		voltagem. Existem certos monitores que so feitos para 
		serem rotacionados.
		Se o seu _NAO_  um desses, mas voc absolutamente precisa
		vir-lo de lado, faa  seu risco.

                *******************************************************
		NO DEIXE SEU MONITOR SEM ATENO SE ELE ESTIVER LIGADO
		E VIRADO DE LADO.
                *******************************************************

-norotate     	Este comando deve desabilitar todas as rotaes internas
		da imagem, portanto mostrando a imagem como ela deve ser
		(voce precisar de um monitor vertical pra ver jogos verticais)
		Entretanto, muitos drivers ainda no usam a rotao centra-
		lizada do MAME, mas ao contrrio, rotacionam a imagem por si
		proprios, nesses casos -norotate nao possui efeito algum.
		Em alguns casos a imagem estar de cabea pra baixo, use
               -norotate -flipx -flipy para corrigir isso.

-soundcard n  	Seleciona uma placa de som (se no especificado, vc ser
		perguntado interativamente)

-sr n         	Seta a taxa de amostragem. O padro  22050. Valores menores
		(ex: 11025) causam piora da qualidade de som, porem emulao
		mais rpida. Valores altos (ex: 44100) causam qualidade de som
		melhor porem diminuem a velocidade da emulao.

-sb n		Seta os bits da amostra de audio, 8 ou 16. O padro  8.
		16 ir melhorar a qualidade em alguns jogos, mas diminuir 
		a velocidade. Isso  uma configura!ao de software, no de
		hardware. A placa de som ir sempre estar em 16 bits, caso
		seja possvel isso.
-stereo/-nostereo (default: -stereo)
		habilita som Stereo para jogos que suportam. 
             
-joy n (default: none) permite uso de joystick, n pode ser:
                0/none       - no joystick
                1/standard   - normal 2 button joystick
                2/dual       - dual joysticks
                3/button4    - Stick/Pad with 4 buttons
                4/button6    - Stick/Pad with 6 buttons
                5/button8    - Stick/Pad with 8 buttons
                6/fspro      - CH Flightstick Pro
                7/wingex     - Wingman Extreme
                           - Wingman Warrior without spinner
                8/sidewinder - Microsoft Sidewinder (up to 4)
                9/gamepadpro - Gravis GamePad Pro
                sneslpt1     - SNES pad on LPT1 (needs special hardware)
                sneslpt2     - SNES pad on LPT2 (needs special hardware)
                sneslpt3     - SNES pad on LPT3 (needs special hardware)

                Notas:
                1) Use o menu TAB par acalibrar joysticks analgicos. Os dados
		  da calibrao ficar salvos em MAME.CFG. Se vc estiver usando
		  diferentes tipos de joystick para diferentes jogos, voc ter
		  que recalibrar seu joystick toda vez.
	        2) Descries de joystick por numeros pode nao ser suportada
		  pelo MAME no futuro. Use o nome simblico.
	        3) Botoes extra de joysticks desconhecidos (sem marca) podem
		  nao funcionar.
	        4) O site "oficial" do Snespad-Suport :
                  http://snespad.emulationworld.com

-ym3812opl/-noym3812opl (default: -ym3812opl) usa o chip OPL da Soundblaster para
		a emulaao de musica do chip YM3812. Isso  mais rpido e 
		razoavelmente fiel ja que os chips so 100% compatveis. No entanto
		o pitch pode estar errado. Note tambm que com -no3812opl voc
		precisar de samples externas de percurso.
-log            cria um log de acessos ilegais de memoria em ERROR.LOG
-help, -?       Mostra a verso atual do MAME e notas de copyright
-list           mostra uma lista dos jogos suportados
-listfull       mostra uma lista dos nomes dos diretorios dos jogos + uma descrio 
-listroms       mostra as ROMs necessrias para determinado jogo
-listsamples    mostra as Samples necessrias para determinado jogo
-listdetails    mostra uma lista detalhada de drivers e o hardware que utilizam 
-listgames      lista os jogos suportados, ano, fabricante
-listinfo       lista detalhada para todos os jogos suportados
-listclones     lista todos os clones para determinado jogo
-verifyroms     checa o jogo selecionado por ROMs que faltam ou esto incorretas
-verifysamples  checa as Samples para o jogo selecionado
-romdir         Especifica um diretrio ou zip alternado onde esto as ROMs para
		determinado jogo. Ex: "mame pcaman -romdir pachack" vai rodar o 
		jogo PacMan mas carregar as ROms de um diretorio nomeado como
		"pachack" ou um arquivo "packhack.zip"
-mouse/-nomouse (default: -mouse) habilita/desabilita o suporte ao mouse
-frameskip n    (default: auto)
		pula quadros para acelerar a emulao. O argumento  o numero
		de quadros (at 12) a se pular. Por exemplo, se o jogo normalmente
		roda a 60 quadros por segundo, "-frameskip 2" vai fora-lo a rodar
		a 50 quadros por segundo e "-frameskip 6" a 30 quadros. Use F11 
		para checar a velocidade que seu computador est alcanando.
		Se ela est menos de 100%, aumente o valor do frameskip. Voc pode
		pressionar F9 para mudar o valor enquanto o jogo est rodando.
		Quando setada para AUTO (o padro), o valor do frameskip  
		dinamicamente ajustado no tempo de execuo para mostrar o maximo
		possvel de quadros sem que a velocidada caia abaixo de 100%.
-antialias/-noantialias (default: -antialias)
                antialiasing para jogos de vetor.
-beam n         set a largura em pixel para os vetores. n  um float no alcance de
		1.00 at 16.00.
-flicker n      faz os vetores piscarem. n  um argumento opcional, um float no
		alcance de 0.00 - 100.00 (0=nada 100=maximo).
-translucency/-notranslucency (default: -translucency)
                ativa ou desativa translucencia do vetor.
-cheat          Cheats como a aceleracao em PacMan ou pulo de fases em muitos jogos
                esto desativados como padro. Use essa opo para ativa-los
-debug          AAtiva o debugger integrado. Durante a emulao, aperte
                tilde para entrar no debugger. Isso  apenas disponvel caso o MAME 
		tenha sid compilado com MAME_DEBUG definido.
-profiler       ativa o profiler. Aperte Shift+F11 para mostra-lo na tela.
-record name    Grava entrada do Joystick em arquivo INP/name.inp.
-playback name  Reproduz a entrada do joystick gravada em arquivo INP/name.inp.
-savecfg        no mais suportada no momento.
-ignorecfg      Ignora o arquivo MAME.CFG e inicia com valores padro.



Teclas
------
Tab          Ativa/desativa o menu de configurao
Tilde        Ativa/Desativa "On Screen Display"
P            Pausa
F3           Reset
F4           Mostra os grficos do jogo. use os cursores para mudar/setar as cores,
             F4 ou Esc para retornar  emulao.
F9           Change frame skip on the fly
F10          Ativa/Desativa speed throttling
F11          Ativa/Desativa display de velocidade
F12          Salva um arquivo com 'foto' da tela. O diretrio padro para se salvar
		o arquivo  o diretorio PCX, voc deve cria-lo mamualmente, ele no
		ser criado automaticamente pelo programa caso nao exista.
ESC          Sai do emulador


   --------------------------------------------------------------------------
    README.TXT traduzido para o Portugus (Brasil) por: Rafael Prado Rocchi
      Se tiver duvida ou sugesto sobre a traduo contacte-me via e-mail
                 no seguinte endereo: brmame@zipmail.com.br
                             ------------------------
          No envie suas sugestes e/ou dvidas sobre a traduo para o 
                    MAME Team pois eles no iro lhe responder.
  --------------------------------------------------------------------------
